@@ -8,7 +8,8 @@ httpget <- function(){
   }
 
   #extract path
-  reqpath <- strsplit(substring(curl::curl_unescape(req$path_info()), 2),"/")[[1]];
+  clean_path <- gsub("//", "/", req$path_info(), fixed = TRUE)
+  reqpath <- strsplit(substring(curl::curl_unescape(clean_path), 2),"/")[[1]];
 
   if(!length(reqpath)){
     res$checkmethod();
